@@ -31,12 +31,12 @@
 #include <QGridLayout>
 #include <QLabel>
 #include <QPushButton>
+#include <QRegularExpression>
 #include <QWidget>
-#include "Common.h"
-#include "DialogSettings.h"
 #include "FilterTextTranslator.h"
 #include "HtmlTranslator.h"
 #include "IconLoader.h"
+#include "Settings.h"
 
 namespace GmicQt
 {
@@ -73,8 +73,9 @@ bool FileParameter::addTo(QWidget * widget, int row)
   _button = new QPushButton(buttonText, widget);
   _button->setIcon(LOAD_ICON("document-open"));
   _grid->addWidget(_label = new QLabel(_name, widget), row, 0, 1, 1);
+  setTextSelectable(_label);
   _grid->addWidget(_button, row, 1, 1, 2);
-  connect(_button, SIGNAL(clicked()), this, SLOT(onButtonPressed()));
+  connect(_button, &QPushButton::clicked, this, &FileParameter::onButtonPressed);
   return true;
 }
 
@@ -107,7 +108,7 @@ void FileParameter::reset()
   setValue(_default);
 }
 
-bool FileParameter::initFromText(const char * text, int & textLength)
+bool FileParameter::initFromText(const QString & filterName, const char * text, int & textLength)
 {
   QList<QString> list;
   if (matchType("filein", text)) {
@@ -123,11 +124,11 @@ bool FileParameter::initFromText(const char * text, int & textLength)
   if (list.isEmpty()) {
     return false;
   }
-  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
-  QRegExp re("^\".*\"$");
-  if (re.exactMatch(list[1])) {
-    list[1].chop(1);
-    list[1].remove(0, 1);
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0], filterName));
+  QRegularExpression re("^\"(.*)\"$");
+  QRegularExpressionMatch match = re.match(list[1]);
+  if (match.hasMatch()) {
+    list[1] = match.captured(1);
   }
   _default = _value = list[1];
   return true;
@@ -142,7 +143,7 @@ void FileParameter::onButtonPressed()
 {
   QString folder;
   if (_value.isEmpty()) {
-    folder = DialogSettings::FileParameterDefaultPath;
+    folder = Settings::FileParameterDefaultPath;
   } else {
     folder = QFileInfo(_value).path();
   }
@@ -151,17 +152,18 @@ void FileParameter::onButtonPressed()
   }
 
   QString filename;
+  const QFileDialog::Options options = Settings::nativeFileDialogs() ? QFileDialog::Options() : QFileDialog::DontUseNativeDialog;
 
   switch (_dialogMode) {
   case DialogMode::Input:
-    filename = QFileDialog::getOpenFileName(QApplication::topLevelWidgets().at(0), tr("Select a file"), folder, QString(), nullptr);
+    filename = QFileDialog::getOpenFileName(QApplication::topLevelWidgets().at(0), tr("Select a file"), folder, QString(), nullptr, options);
     break;
   case DialogMode::Output:
-    filename = QFileDialog::getSaveFileName(QApplication::topLevelWidgets().at(0), tr("Select a file"), folder, QString(), nullptr);
+    filename = QFileDialog::getSaveFileName(QApplication::topLevelWidgets().at(0), tr("Select a file"), folder, QString(), nullptr, options);
     break;
   case DialogMode::InputOutput: {
     QFileDialog dialog(dynamic_cast<QWidget *>(parent()), tr("Select a file"), folder, QString());
-    dialog.setOptions(QFileDialog::DontConfirmOverwrite | QFileDialog::DontUseNativeDialog);
+    dialog.setOptions(QFileDialog::DontConfirmOverwrite | options);
     dialog.setFileMode(QFileDialog::AnyFile);
     if (!_value.isEmpty()) {
       dialog.selectFile(_value);
@@ -180,7 +182,7 @@ void FileParameter::onButtonPressed()
   } else {
     _value = filename;
     QFileInfo info(filename);
-    DialogSettings::FileParameterDefaultPath = info.path();
+    Settings::FileParameterDefaultPath = info.path();
     int w = _button->contentsRect().width() - 10;
     QFontMetrics fm(_button->font());
     _button->setText(fm.elidedText(QFileInfo(_value).fileName(), Qt::ElideRight, w));
