@@ -46,9 +46,7 @@
 #include "CroppedImageListProxy.h"
 #include "DialogSettings.h"
 #include "FilterSelector/FavesModelReader.h"
-#include "FilterSelector/FilterTagMap.h"
 #include "FilterSelector/FiltersPresenter.h"
-#include "FilterSelector/FiltersVisibilityMap.h"
 #include "FilterTextTranslator.h"
 #include "Globals.h"
 #include "GmicStdlib.h"
@@ -116,7 +114,7 @@ MainWindow::MainWindow(QWidget * parent) : QMainWindow(parent), ui(new Ui::MainW
 
   QShortcut * copyShortcut = new QShortcut(QKeySequence::Copy, this);
   copyShortcut->setContext(Qt::ApplicationShortcut);
-  connect(copyShortcut, &QShortcut::activated, [this] { ui->tbCopyCommand->animateClick(100); });
+  connect(copyShortcut, &QShortcut::activated, [this] { ui->tbCopyCommand->animateClick(); });
   ui->tbCopyCommand->setToolTip(appendShortcutText(tr("Copy G'MIC command to clipboard"), copyShortcut->key()));
   ui->tbCopyCommand->setVisible(false);
 
@@ -148,6 +146,7 @@ MainWindow::MainWindow(QWidget * parent) : QMainWindow(parent), ui(new Ui::MainW
   ui->progressInfoWidget->hide();
   ui->messageLabel->setText(QString());
   ui->messageLabel->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+  ui->rightMessageLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
   ui->filterParams->setNoFilter();
   _pendingActionAfterCurrentProcessing = ProcessingAction::NoAction;
@@ -315,6 +314,7 @@ void MainWindow::setDarkTheme()
                       "QMenu::item:selected { background: rgb(110,110,110); }"
                       "QTextEdit { background: #505050; }"
                       "QSpinBox  { background: #505050; }"
+                      "QListWidget { background: #505050; }"
                       "QDoubleSpinBox { background: #505050; }"
                       "QToolButton:checked { background: #383838; }"
                       "QToolButton:pressed { background: #383838; }"
@@ -475,6 +475,12 @@ QString MainWindow::screenGeometries()
   return geometries.join(QString());
 }
 
+void MainWindow::updateFilters(bool internet)
+{
+  ui->tbUpdateFilters->setEnabled(false);
+  updateFiltersFromSources(0, internet);
+}
+
 void MainWindow::onStartupFiltersUpdateFinished(int status)
 {
   bool ok = QObject::disconnect(Updater::getInstance(), &Updater::updateIsDone, this, &MainWindow::onStartupFiltersUpdateFinished);
@@ -581,14 +587,26 @@ void MainWindow::onEscapeKeyPressed()
 
 void MainWindow::clearMessage()
 {
+  ui->messageLabel->setText(QString());
   if (!_messageTimerID) {
     return;
   }
   killTimer(_messageTimerID);
-  ui->messageLabel->setText(QString());
   _messageTimerID = 0;
 }
 
+void MainWindow::clearRightMessage()
+{
+  ui->rightMessageLabel->hide();
+  ui->rightMessageLabel->clear();
+}
+
+void MainWindow::showRightMessage(const QString & text)
+{
+  ui->rightMessageLabel->setText(text);
+  ui->rightMessageLabel->show();
+}
+
 void MainWindow::timerEvent(QTimerEvent * e)
 {
   if (e->timerId() == _messageTimerID) {
@@ -601,9 +619,11 @@ void MainWindow::timerEvent(QTimerEvent * e)
 void MainWindow::showMessage(const QString & text, int ms)
 {
   clearMessage();
-  if (!text.isEmpty() && ms) {
+  if (!text.isEmpty()) {
     ui->messageLabel->setText(text);
-    _messageTimerID = startTimer(ms);
+    if (ms) {
+      _messageTimerID = startTimer(ms);
+    }
   }
 }
 
@@ -660,6 +680,8 @@ void MainWindow::makeConnections()
 
 void MainWindow::onPreviewUpdateRequested()
 {
+  clearMessage();
+  clearRightMessage();
   onPreviewUpdateRequested(false);
 }
 
@@ -869,6 +891,9 @@ void MainWindow::onFullImageProcessingDone()
     ui->previewWidget->updateFullImageSizeIfDifferent(extent);
     ui->previewWidget->sendUpdateRequest();
     _okButtonShouldApply = false;
+    if (_pendingActionAfterCurrentProcessing == ProcessingAction::Apply) {
+      showRightMessage(QString(tr("[Elapsed time: %1]")).arg(readableDuration(_processor.lastCompletedExecutionTime())));
+    }
   }
 }
 
@@ -892,6 +917,8 @@ void MainWindow::search(const QString & text)
 
 void MainWindow::onApplyClicked()
 {
+  clearMessage();
+  clearRightMessage();
   _pendingActionAfterCurrentProcessing = ProcessingAction::Apply;
   processImage();
 }
@@ -904,6 +931,8 @@ void MainWindow::onOkClicked()
     return;
   }
   if (_okButtonShouldApply) {
+    clearMessage();
+    clearRightMessage();
     _pendingActionAfterCurrentProcessing = ProcessingAction::Ok;
     processImage();
   } else {
@@ -914,7 +943,6 @@ void MainWindow::onOkClicked()
 
 void MainWindow::onCancelClicked()
 {
-  TIMING;
   if (_processor.isProcessing() && confirmAbortProcessingOnCloseRequest()) {
     if (_processor.isProcessing()) {
       _pendingActionAfterCurrentProcessing = ProcessingAction::Close;
@@ -979,8 +1007,7 @@ void MainWindow::onPreviewZoomReset()
 
 void MainWindow::onUpdateFiltersClicked()
 {
-  ui->tbUpdateFilters->setEnabled(false);
-  updateFiltersFromSources(0, ui->cbInternetUpdate->isChecked());
+  updateFilters(ui->cbInternetUpdate->isChecked());
 }
 
 void MainWindow::saveCurrentParameters()
@@ -1039,7 +1066,6 @@ void MainWindow::loadSettings()
 {
   QSettings settings;
   _filtersPresenter->loadSettings(settings);
-
   _lastExecutionOK = settings.value("LastExecution/ExitedNormally", true).toBool();
   _newSession = host_app_pid() != settings.value("LastExecution/HostApplicationID", 0).toUInt();
   settings.setValue("LastExecution/ExitedNormally", false);
@@ -1397,6 +1423,13 @@ void MainWindow::onSettingsClicked()
     }
   }
   showZoomWarningIfNeeded();
+  // Sources modification may require an update
+  bool sourcesModified = false;
+  bool sourcesRequireInternetUpdate = false;
+  dialog.sourcesStatus(sourcesModified, sourcesRequireInternetUpdate);
+  if (sourcesModified) {
+    updateFilters(sourcesRequireInternetUpdate && ui->cbInternetUpdate->isChecked());
+  }
 }
 
 bool MainWindow::confirmAbortProcessingOnCloseRequest()
