@@ -12,12 +12,12 @@
         <translation>對話框</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="238"/>
+        <location filename="../ui/dialogsettings.ui" line="250"/>
         <source>Internet updates</source>
         <translation>網際網路更新</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="247"/>
+        <location filename="../ui/dialogsettings.ui" line="259"/>
         <source>Update now</source>
         <translation>立即更新</translation>
     </message>
@@ -83,21 +83,31 @@
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="209"/>
-        <source>&amp;Enable High-DPI support</source>
+        <source>Use native file dialog</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <location filename="../ui/dialogsettings.ui" line="216"/>
+        <source>&amp;Enable High-DPI support</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="223"/>
         <source>&lt;i&gt;(Restart needed)&lt;/i&gt;</source>
         <translation type="unfinished">&lt;i&gt;（需要重啟程式）&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="232"/>
+        <location filename="../ui/dialogsettings.ui" line="239"/>
+        <source>Filter sources</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/dialogsettings.ui" line="244"/>
         <source>Other</source>
         <translation>其他</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="270"/>
+        <location filename="../ui/dialogsettings.ui" line="282"/>
         <source>Output messages</source>
         <translation>輸出訊息</translation>
     </message>
@@ -122,12 +132,12 @@
         <translation>顯示機構標誌</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="279"/>
+        <location filename="../ui/dialogsettings.ui" line="291"/>
         <source>Notify when scheduled update fails</source>
         <translation>在定期更新失敗時通知</translation>
     </message>
     <message>
-        <location filename="../ui/dialogsettings.ui" line="321"/>
+        <location filename="../ui/dialogsettings.ui" line="333"/>
         <source>&amp;Ok</source>
         <translation>確定(&amp;O)</translation>
     </message>
@@ -143,7 +153,7 @@
 <context>
     <name>GmicQt::ColorParameter</name>
     <message>
-        <location filename="../src/FilterParameters/ColorParameter.cpp" line="201"/>
+        <location filename="../src/FilterParameters/ColorParameter.cpp" line="200"/>
         <source>Select color</source>
         <translation>選取色彩</translation>
     </message>
@@ -230,13 +240,18 @@
         <source>Check to use Native/OS color dialog, uncheck to use Qt&apos;s</source>
         <translation>核取以使用系統原生的色彩對話框，不核取則使用 Qt 提供的版本</translation>
     </message>
+    <message>
+        <location filename="../src/DialogSettings.cpp" line="90"/>
+        <source>Check to use Native/OS file dialog, uncheck to use Qt&apos;s</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>GmicQt::FileParameter</name>
     <message>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="158"/>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="161"/>
-        <location filename="../src/FilterParameters/FileParameter.cpp" line="164"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="159"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="162"/>
+        <location filename="../src/FilterParameters/FileParameter.cpp" line="165"/>
         <source>Select a file</source>
         <translation>選擇檔案</translation>
     </message>
@@ -267,12 +282,12 @@
 <context>
     <name>GmicQt::FiltersPresenter</name>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="499"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="510"/>
         <source>Unknown filter</source>
         <translation>不明的濾鏡</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="609"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="620"/>
         <source>Cannot find this fave&apos;s original filter
 </source>
         <translation>找不到這最愛濾鏡的來源濾鏡
@@ -287,42 +302,42 @@
         <translation>從最愛移除</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="675"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="679"/>
         <source>Rename Fave</source>
         <translation>重新命名最愛</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="677"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="681"/>
         <source>Remove Fave</source>
         <translation>從最愛移除</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="679"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="683"/>
         <source>Clone Fave</source>
         <translation>再製最愛</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="683"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="687"/>
         <source>Add Fave</source>
         <translation>加到最愛</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="702"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="706"/>
         <source>Remove All</source>
         <translation>移除全部</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="709"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="713"/>
         <source>%1 (%2 %3)</source>
         <translation>%1 (%2 %3)</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="709"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="713"/>
         <source>Filters</source>
         <translation>濾鏡</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="709"/>
+        <location filename="../src/FilterSelector/FiltersView/FiltersView.cpp" line="713"/>
         <source>Filter</source>
         <translation>濾鏡</translation>
     </message>
@@ -341,7 +356,7 @@
 <context>
     <name>GmicQt::FolderParameter</name>
     <message>
-        <location filename="../src/FilterParameters/FolderParameter.cpp" line="136"/>
+        <location filename="../src/FilterParameters/FolderParameter.cpp" line="138"/>
         <source>Select a folder</source>
         <translation>選擇資料夾</translation>
     </message>
@@ -349,12 +364,12 @@
 <context>
     <name>GmicQt::GmicProcessor</name>
     <message>
-        <location filename="../src/GmicProcessor.cpp" line="345"/>
+        <location filename="../src/GmicProcessor.cpp" line="349"/>
         <source>Image #%1 returned by filter has %2 channels (should be at most 4)</source>
         <translation>濾鏡傳回的影像 #%1 含有 %2 個通道（應為不多於 4 個）</translation>
     </message>
     <message>
-        <location filename="../src/GmicProcessor.cpp" line="380"/>
+        <location filename="../src/GmicProcessor.cpp" line="385"/>
         <source>Image #%1 returned by filter has %2 channels
 (should be at most 4)</source>
         <translation>濾鏡傳回的影像 #%1 含有 %2 個通道
@@ -364,22 +379,22 @@
 <context>
     <name>GmicQt::HeadlessProcessor</name>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="84"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="79"/>
         <source>At least a filter path or a filter command must be provided.</source>
         <translation>必須提供濾鏡路徑或濾鏡命令。</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="86"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="81"/>
         <source>Custom command (%1)</source>
         <translation>自訂命令 (%1)</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="94"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="89"/>
         <source>Cannot find filter matching path %1</source>
         <translation>找不到符合路徑「%1」的濾鏡</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="101"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="96"/>
         <source>Error parsing filter parameters definition for filter:
 
 %1
@@ -396,17 +411,17 @@ Cannot retrieve default parameters.
 %2</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="119"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="114"/>
         <source>Error parsing supplied command: %1</source>
         <translation>解析所提供的命令時出現錯誤：%1</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="122"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="117"/>
         <source>Supplied command (%1) does not match path (%2), (should be %3).</source>
         <translation>所提供的命令 (%1) 不符合路徑 (%2)（應為 %3）。</translation>
     </message>
     <message>
-        <location filename="../src/HeadlessProcessor.cpp" line="234"/>
+        <location filename="../src/HeadlessProcessor.cpp" line="229"/>
         <source>Filter execution failed, but with no error message.</source>
         <translation>濾鏡執行失敗，但沒有錯誤訊息。</translation>
     </message>
@@ -510,76 +525,76 @@ Cannot retrieve default parameters.
 <context>
     <name>GmicQt::MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="115"/>
+        <location filename="../src/MainWindow.cpp" line="110"/>
         <source>Add fave</source>
         <translation>加到最愛</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="117"/>
+        <location filename="../src/MainWindow.cpp" line="112"/>
         <source>Reset parameters to default values</source>
         <translation>重設參數到預設值</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="123"/>
+        <location filename="../src/MainWindow.cpp" line="118"/>
         <source>Copy G&apos;MIC command to clipboard</source>
         <translation>複製 G&apos;MIC 命令到剪貼簿</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="130"/>
+        <location filename="../src/MainWindow.cpp" line="125"/>
         <source>Rename fave</source>
         <translation>重新命名最愛</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="132"/>
+        <location filename="../src/MainWindow.cpp" line="127"/>
         <source>Remove fave</source>
         <translation>從最愛移除</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="136"/>
+        <location filename="../src/MainWindow.cpp" line="131"/>
         <source>Expand/Collapse all</source>
         <translation>全部展開或折疊</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="138"/>
+        <location filename="../src/MainWindow.cpp" line="133"/>
         <source>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;Normandy University (https://www.unicaen.fr)&lt;br/&gt;Ensicaen (https://www.ensicaen.fr)</source>
         <translation>G&apos;MIC (https://gmic.eu)&lt;br/&gt;GREYC (https://www.greyc.fr)&lt;br/&gt;CNRS (https://www.cnrs.fr)&lt;br/&gt;諾曼第大學 (https://www.unicaen.fr)&lt;br/&gt;ENSICAEN (https://www.ensicaen.fr)</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="145"/>
+        <location filename="../src/MainWindow.cpp" line="140"/>
         <source>Selection mode</source>
         <translation>選取模式</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="183"/>
+        <location filename="../src/MainWindow.cpp" line="179"/>
         <source>Update filters</source>
         <translation>更新濾鏡</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="237"/>
+        <location filename="../src/MainWindow.cpp" line="233"/>
         <source>Manage visible tags
 (Right-click on a fave or a filter to set/remove tags)</source>
         <translation>管理可見標籤
 （右鍵點選最愛或濾鏡，以設定或移除標籤）</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="359"/>
+        <location filename="../src/MainWindow.cpp" line="356"/>
         <source>Update completed</source>
         <translation>更新完成</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="359"/>
-        <location filename="../src/MainWindow.cpp" line="361"/>
-        <location filename="../src/MainWindow.cpp" line="493"/>
+        <location filename="../src/MainWindow.cpp" line="356"/>
+        <location filename="../src/MainWindow.cpp" line="358"/>
+        <location filename="../src/MainWindow.cpp" line="496"/>
         <source>Filter definitions have been updated.</source>
         <translation>濾鏡定義已更新。</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="364"/>
+        <location filename="../src/MainWindow.cpp" line="361"/>
         <source>No download was needed.</source>
         <translation>無需下載。</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="417"/>
+        <location filename="../src/MainWindow.cpp" line="414"/>
         <source>Plugin was called with a filter path with no matching filter:
 
 Path: %1</source>
@@ -588,8 +603,8 @@ Path: %1</source>
 路徑為：%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="425"/>
-        <location filename="../src/MainWindow.cpp" line="452"/>
+        <location filename="../src/MainWindow.cpp" line="422"/>
+        <location filename="../src/MainWindow.cpp" line="449"/>
         <source>Error parsing filter parameters definition for filter:
 
 %1
@@ -606,7 +621,7 @@ Cannot retrieve default parameters.
 %2</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="438"/>
+        <location filename="../src/MainWindow.cpp" line="435"/>
         <source>Plugin was called with a command that cannot be recognized as a filter:
 
 Command: %1</source>
@@ -615,7 +630,12 @@ Command: %1</source>
 命令：%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="433"/>
+        <location filename="../src/MainWindow.cpp" line="895"/>
+        <source>[Elapsed time: %1]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="430"/>
         <source>Plugin was called with a command that cannot be parsed:
 
 %1</source>
@@ -624,7 +644,7 @@ Command: %1</source>
 %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="442"/>
+        <location filename="../src/MainWindow.cpp" line="439"/>
         <source>Plugin was called with a command that does not match the provided path:
 
 Path: %1
@@ -637,52 +657,52 @@ Command found for this path : %3</source>
 路徑中找到的命令：%3</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="489"/>
+        <location filename="../src/MainWindow.cpp" line="492"/>
         <source>Filters update could not be achieved</source>
         <translation>無法完成濾鏡更新</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="615"/>
+        <location filename="../src/MainWindow.cpp" line="632"/>
         <source>The update could not be achieved&lt;br&gt;because of the following errors:&lt;br&gt;</source>
         <translation>由於發生以下錯誤，&lt;br&gt;無法完成更新：&lt;br&gt;</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="621"/>
+        <location filename="../src/MainWindow.cpp" line="638"/>
         <source>Update error</source>
         <translation>更新錯誤</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="810"/>
+        <location filename="../src/MainWindow.cpp" line="829"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="925"/>
+        <location filename="../src/MainWindow.cpp" line="951"/>
         <source>Waiting for cancelled jobs...</source>
         <translation>正在等待取消工作……</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1291"/>
+        <location filename="../src/MainWindow.cpp" line="1315"/>
         <source>Import faves</source>
         <translation>匯入最愛</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1291"/>
+        <location filename="../src/MainWindow.cpp" line="1315"/>
         <source>Do you want to import faves from file below?&lt;br/&gt;%1</source>
         <translation>你要從以下檔案匯入最愛嗎？&lt;br/&gt;%1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1294"/>
+        <location filename="../src/MainWindow.cpp" line="1318"/>
         <source>Don&apos;t ask again</source>
         <translation>不再詢問</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1406"/>
+        <location filename="../src/MainWindow.cpp" line="1437"/>
         <source>Confirmation</source>
         <translation>確認</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="1406"/>
+        <location filename="../src/MainWindow.cpp" line="1437"/>
         <source>A gmic command is running.&lt;br&gt;Do you really want to close the plugin?</source>
         <translation>一項 gmic 命令正在執行中。&lt;br&gt;你確定要關閉外掛程式嗎？</translation>
     </message>
@@ -698,17 +718,17 @@ Command found for this path : %3</source>
 <context>
     <name>GmicQt::ProgressInfoWidget</name>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="48"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="49"/>
         <source>G&apos;MIC-Qt Plug-in progression</source>
         <translation>G&apos;MIC-Qt 外掛程式進度</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="51"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="52"/>
         <source>Abort</source>
         <translation>中止</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="149"/>
+        <location filename="../src/Widgets/ProgressInfoWidget.cpp" line="150"/>
         <source>Updating filters...</source>
         <translation>正在更新濾鏡……</translation>
     </message>
@@ -727,22 +747,22 @@ Command found for this path : %3</source>
 <context>
     <name>GmicQt::ProgressInfoWindow</name>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="52"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="49"/>
         <source>G&apos;MIC-Qt Plug-in progression</source>
         <translation>G&apos;MIC-Qt 外掛程式進度</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="144"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="141"/>
         <source>%1 seconds</source>
         <translation>%1 秒</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="154"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="151"/>
         <source>[Processing %1 | %2]</source>
         <translation>[正在處理 %1 | %2]</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="156"/>
+        <location filename="../src/Widgets/ProgressInfoWindow.cpp" line="153"/>
         <source>[Processing %1]</source>
         <translation>[正在處理 %1]</translation>
     </message>
@@ -760,30 +780,105 @@ Command found for this path : %3</source>
         <translation>在濾鏡清單中搜尋 (%1)</translation>
     </message>
 </context>
+<context>
+    <name>GmicQt::SourcesWidget</name>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="47"/>
+        <source>Move source up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="49"/>
+        <source>Move source down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="51"/>
+        <source>Remove source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="53"/>
+        <source>Add local file (dialog)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="55"/>
+        <source>Reset filter sources</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="78"/>
+        <source>Macros: $HOME %APPDATA% $VERSION</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="80"/>
+        <source>Macros: $HOME $VERSION</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="83"/>
+        <source>Disable</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="84"/>
+        <source>Enable without updates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="85"/>
+        <source>Enable with updates (recommended)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="100"/>
+        <source>Environment variables (e.g. %APPDATA% or %HOMEDIR%) are substituted in sources.
+VERSION is also a predefined variable that stands for the G&apos;MIC version number (currently %1).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="104"/>
+        <source>Environment variables (e.g. $HOME or ${HOME} for your home directory) are substituted in sources.
+VERSION is also a predefined variable that stands for the G&apos;MIC version number (currently %1).</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="109"/>
+        <source>New source</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/SourcesWidget.cpp" line="185"/>
+        <source>Select a file</source>
+        <translation type="unfinished">選擇檔案</translation>
+    </message>
+</context>
 <context>
     <name>GmicQt::Updater</name>
     <message>
-        <location filename="../src/Updater.cpp" line="202"/>
+        <location filename="../src/Updater.cpp" line="136"/>
         <source>Error downloading %1 (empty file?)</source>
         <translation>下載「%1」時出現錯誤（空白檔案？）</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="211"/>
+        <location filename="../src/Updater.cpp" line="145"/>
         <source>Could not read/decompress %1</source>
         <translation>不能讀取或解壓縮「%1」</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="216"/>
+        <location filename="../src/Updater.cpp" line="150"/>
         <source>Error writing file %1</source>
         <translation>寫入檔案「%1」時出現錯誤</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="233"/>
+        <location filename="../src/Updater.cpp" line="167"/>
         <source>Error downloading %1&lt;br/&gt;Error %2: %3</source>
         <translation>下載「%1」時出現錯誤&lt;br/&gt;錯誤 %2：%3</translation>
     </message>
     <message>
-        <location filename="../src/Updater.cpp" line="269"/>
+        <location filename="../src/Updater.cpp" line="203"/>
         <source>Download timeout: %1</source>
         <translation>下載逾時：%1</translation>
     </message>
@@ -804,22 +899,22 @@ Command found for this path : %3</source>
 <context>
     <name>GmicQt::ZoomLevelSelector</name>
     <message>
-        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="53"/>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="54"/>
         <source>Zoom in</source>
         <translation>放大</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="54"/>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="55"/>
         <source>Zoom out</source>
         <translation>縮小</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="55"/>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="56"/>
         <source>Reset zoom</source>
         <translation>重設縮放比例</translation>
     </message>
     <message>
-        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="154"/>
+        <location filename="../src/Widgets/ZoomLevelSelector.cpp" line="155"/>
         <source>Warning: Preview may be inaccurate (zoom factor has been modified)</source>
         <translation>警告：預覽可能不準確（縮放比例已修改）</translation>
     </message>
@@ -869,7 +964,7 @@ Command found for this path : %3</source>
     </message>
     <message>
         <location filename="../src/Host/None/jpegqualitydialog.ui" line="20"/>
-        <location filename="../src/Host/None/JpegQualityDialog.cpp" line="12"/>
+        <location filename="../src/Host/None/JpegQualityDialog.cpp" line="13"/>
         <source>JPEG Quality</source>
         <translation>JPEG 品質</translation>
     </message>
@@ -962,26 +1057,27 @@ Command found for this path : %3</source>
     </message>
     <message>
         <location filename="../ui/mainwindow.ui" line="511"/>
+        <location filename="../ui/mainwindow.ui" line="518"/>
         <source>TextLabel</source>
         <translation>TextLabel</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="524"/>
+        <location filename="../ui/mainwindow.ui" line="531"/>
         <source>&amp;Cancel</source>
         <translation>取消(&amp;C)</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="537"/>
+        <location filename="../ui/mainwindow.ui" line="544"/>
         <source>&amp;Fullscreen</source>
         <translation>全螢幕(&amp;F)</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="550"/>
+        <location filename="../ui/mainwindow.ui" line="557"/>
         <source>&amp;Apply</source>
         <translation>套用(&amp;A)</translation>
     </message>
     <message>
-        <location filename="../ui/mainwindow.ui" line="563"/>
+        <location filename="../ui/mainwindow.ui" line="570"/>
         <source>&amp;OK</source>
         <translation>確定(&amp;O)</translation>
     </message>
@@ -1044,27 +1140,27 @@ Command found for this path : %3</source>
         <translation>可見</translation>
     </message>
     <message>
-        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="104"/>
+        <location filename="../src/FilterSelector/FiltersPresenter.cpp" line="106"/>
         <source>Available filters (%1)</source>
         <translation>可用的濾鏡 (%1)</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="77"/>
+        <location filename="../src/Host/None/host_none.cpp" line="76"/>
         <source>Select an image to open...</source>
         <translation>開啟影像…</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="83"/>
+        <location filename="../src/Host/None/host_none.cpp" line="84"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="83"/>
+        <location filename="../src/Host/None/host_none.cpp" line="84"/>
         <source>Could not open file.</source>
         <translation>無法開啟檔案。</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/host_none.cpp" line="87"/>
+        <location filename="../src/Host/None/host_none.cpp" line="88"/>
         <source>Default image</source>
         <translation>預設影像</translation>
     </message>
@@ -1119,7 +1215,7 @@ Command found for this path : %3</source>
         <translation>無法載入翻譯檔「%1」</translation>
     </message>
     <message>
-        <location filename="../src/Misc.cpp" line="333"/>
+        <location filename="../src/Misc.cpp" line="336"/>
         <source>List %1 cannot be merged considering these runs: %2</source>
         <translation>無法合併清單 %1，關聯的執行次：%2</translation>
     </message>
@@ -1132,6 +1228,43 @@ Command found for this path : %3</source>
         <translation>Frame</translation>
     </message>
 </context>
+<context>
+    <name>SourcesWidget</name>
+    <message>
+        <location filename="../ui/sourceswidget.ui" line="14"/>
+        <source>Form</source>
+        <translation type="unfinished">GMIC</translation>
+    </message>
+    <message>
+        <location filename="../ui/sourceswidget.ui" line="136"/>
+        <source>Official filters:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/sourceswidget.ui" line="22"/>
+        <source>File / URL</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/sourceswidget.ui" line="32"/>
+        <source>Add new</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../ui/sourceswidget.ui" line="39"/>
+        <location filename="../ui/sourceswidget.ui" line="55"/>
+        <location filename="../ui/sourceswidget.ui" line="62"/>
+        <location filename="../ui/sourceswidget.ui" line="85"/>
+        <location filename="../ui/sourceswidget.ui" line="92"/>
+        <source>...</source>
+        <translation type="unfinished">…</translation>
+    </message>
+    <message>
+        <location filename="../ui/sourceswidget.ui" line="118"/>
+        <source>Macros: $HOME $VERSION</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>ZoomLevelSelector</name>
     <message>
@@ -1143,22 +1276,22 @@ Command found for this path : %3</source>
 <context>
     <name>gmic_qt_standalone::ImageDialog</name>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="74"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="73"/>
         <source>G&apos;MIC-Qt filter output</source>
         <translation>G&apos;MIC-Qt 濾鏡輸出</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="85"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="84"/>
         <source>Close</source>
         <translation>關閉</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="88"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="87"/>
         <source>Save as...</source>
         <translation>另存為…</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="123"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="122"/>
         <source>%1 file (*.%2)</source>
         <translation>%1 檔 (*.%2)</translation>
     </message>
@@ -1171,12 +1304,12 @@ Command found for this path : %3</source>
 <context>
     <name>gmic_qt_standalone::ImageView</name>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="66"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="65"/>
         <source>Error</source>
         <translation>錯誤</translation>
     </message>
     <message>
-        <location filename="../src/Host/None/ImageDialog.cpp" line="66"/>
+        <location filename="../src/Host/None/ImageDialog.cpp" line="65"/>
         <source>Could not write image file %1</source>
         <translation>無法寫入影像檔「%1」</translation>
     </message>
