@@ -56,8 +56,8 @@
 /*
   Uncomment the two lines below if you want to use the CImg library along with the G'MIC library.
  */
-//#include "CImg.h"
-//using namespace cimg_library;
+// #include "CImg.h"
+// using namespace cimg_library;
 
 #include "gmic.h"
 #include <cstdio>
@@ -95,7 +95,7 @@ int main() {
 
   // Second step : Call G'MIC API to process input images.
   //------------------------------------------------------
-  std::fprintf(stderr,"\n- 2st step : Call G'MIC interpreter.\n");
+  std::fprintf(stderr,"\n- 2nd step : Call G'MIC interpreter.\n");
 
   try {
 
